@@ -108,7 +108,6 @@ class HttpTrigger(BaseTrigger):
             )
         except Exception as e:
             yield TriggerEvent({"status": "error", "message": str(e)})
-            # yield TriggerEvent({"status": "error", "message": str(traceback.format_exc())})
 
     @staticmethod
     async def _convert_response(client_response: ClientResponse) -> requests.Response:
@@ -168,6 +167,7 @@ class HttpSensorTrigger(BaseTrigger):
             {
                 "endpoint": self.endpoint,
                 "data": self.data,
+                "method": self.method,
                 "headers": self.headers,
                 "extra_options": self.extra_options,
                 "http_conn_id": self.http_conn_id,
@@ -187,6 +187,7 @@ class HttpSensorTrigger(BaseTrigger):
                     extra_options=self.extra_options,
                 )
                 yield TriggerEvent(True)
+                return
             except AirflowException as exc:
                 if str(exc).startswith("404"):
                     await asyncio.sleep(self.poke_interval)
